@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '1.03'; # VERSION
+our $VERSION = '1.04'; # VERSION
 
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
@@ -42,6 +42,7 @@ around add_file => sub {
             ,
           is_strict      => \$self->is_strict,
           has_version    => \$self->has_version,
+          multiple       => \$self->multiple,
           filename_match => join(", ", @{ $self->filename_match }),
           filenames      => [ sort @filenames ],
         },
@@ -76,6 +77,13 @@ has has_version => (
   default => sub { 1 },
 );
 
+has multiple => (
+  is      => 'ro',
+  isa     => 'Bool',
+  lazy    => 1,
+  default => sub { 0 },
+);
+
 has filename_match => (
   is      => 'ro',
   isa     => 'ArrayRef',
@@ -101,7 +109,7 @@ Dist::Zilla::Plugin::Test::Version - release Test::Version tests
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
@@ -129,6 +137,10 @@ set L<Test::Version has_version|Test::Version/has_version>
 
 set L<Test::Version filename_match|Test::Version/filename_match>
 
+=head2 multiple
+
+set L<Test::Version multiple|Test::Version/multiple>
+
 =head2 finder
 
 This is the name of a L<Dist::Zilla::Role::FileFinder> for finding files to check.
@@ -189,6 +201,7 @@ my @imports = qw( {{ @filenames ? 'version_ok' : 'version_all_ok' }} );
 my $params = {
     is_strict      => {{ $is_strict }},
     has_version    => {{ $has_version }},
+    multiple       => {{ $multiple }},
 {{ $filename_match ? "    filename_match => [ $filename_match ]," : '' }}
 };
 
